@@ -25,8 +25,8 @@ type Service struct {
 }
 
 func New(c service.Config) (Service, error) {
-	if st, _ := os.Stat("/etc/unifi-base-ucore"); st == nil || !st.IsDir() {
-		return Service{}, service.ErrNotSuported
+	if st, _ := os.Stat("/data/unifi"); st == nil {
+		return Service{}, service.ErrNotSupported
 	}
 	srv := Service{
 		Service: systemd.Service{
